==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/outputs/OpenIdConnectRegistrationResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * The configuration settings of the app registration for the custom Open ID Connect provider.
 * @property clientCredential The authentication credentials of the custom Open ID Connect provider.
 * @property clientId The client id of the custom Open ID Connect provider.
 * @property openIdConnectConfiguration The configuration settings of the endpoints used for the custom Open ID Connect provider.
 */
public data class OpenIdConnectRegistrationResponse(
    public val clientCredential: OpenIdConnectClientCredentialResponse? = null,
    public val clientId: String? = null,
    public val openIdConnectConfiguration: OpenIdConnectConfigResponse? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.web.outputs.OpenIdConnectRegistrationResponse):
            OpenIdConnectRegistrationResponse = OpenIdConnectRegistrationResponse(
            clientCredential = javaType.clientCredential().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.web.kotlin.outputs.OpenIdConnectClientCredentialResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            clientId = javaType.clientId().map({ args0 -> args0 }).orElse(null),
            openIdConnectConfiguration = javaType.openIdConnectConfiguration().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.web.kotlin.outputs.OpenIdConnectConfigResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/web/kotlin/outputs/OpenIdConnectRegistrationResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * The configuration settings of the app registration for the custom Open ID Connect provider.
 * @property clientCredential The authentication credentials of the custom Open ID Connect provider.
 * @property clientId The client id of the custom Open ID Connect provider.
 * @property openIdConnectConfiguration The configuration settings of the endpoints used for the custom Open ID Connect provider.
 */
public data class OpenIdConnectRegistrationResponse(
    public val clientCredential: OpenIdConnectClientCredentialResponse? = null,
    public val clientId: String? = null,
    public val openIdConnectConfiguration: OpenIdConnectConfigResponse? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.web.outputs.OpenIdConnectRegistrationResponse): OpenIdConnectRegistrationResponse = OpenIdConnectRegistrationResponse(
            clientCredential = javaType.clientCredential().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.web.kotlin.outputs.OpenIdConnectClientCredentialResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            clientId = javaType.clientId().map({ args0 -> args0 }).orElse(null),
            openIdConnectConfiguration = javaType.openIdConnectConfiguration().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.web.kotlin.outputs.OpenIdConnectConfigResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}
